@@ -1,10 +1,10 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "list-unicode-display" "0.1"
+(define-package "list-unicode-display" "20241119.1152"
   "Search for and list unicode characters by name."
-  '((cl-lib "0.5"))
+  '((emacs "24.3"))
   :url "https://github.com/purcell/list-unicode-display"
-  :commit "59770cf3572bd36c3e9ba044846dc420c0dca09b"
-  :revdesc "59770cf3572b"
+  :commit "68feedd776082c1743588c2b07dbb6539dbe51bf"
+  :revdesc "68feedd77608"
   :keywords '("convenience")
   :authors '(("Steve Purcell" . "steve@sanityinc.com"))
   :maintainers '(("Steve Purcell" . "steve@sanityinc.com")))
